==> ooo_dev_tools-0.16.0-py3-none-any.whl: ooodev/adapter/document/link_target_comp.py <==
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from ooodev.adapter.beans.property_change_implement import PropertyChangeImplement
from ooodev.adapter.beans.vetoable_change_implement import VetoableChangeImplement
from ooodev.adapter.component_base import ComponentBase


if TYPE_CHECKING:
    from com.sun.star.document import LinkTarget  # service


class LinkTargetComp(ComponentBase, PropertyChangeImplement, VetoableChangeImplement):
    """
    Class for managing LinkTarget Component.
    """

    # pylint: disable=unused-argument

    def __init__(self, component: LinkTarget) -> None:
        """
        Constructor

        Args:
            component (LinkTarget): UNO table LinkTarget Component.
        """
        ComponentBase.__init__(self, component)
        generic_args = self._ComponentBase__get_generic_args()  # type: ignore
        PropertyChangeImplement.__init__(self, component=self.component, trigger_args=generic_args)
        VetoableChangeImplement.__init__(self, component=self.component, trigger_args=generic_args)

    # region Overrides
    def _ComponentBase__get_supported_service_names(self) -> tuple[str, ...]:
        """Returns a tuple of supported service names."""
        return ("com.sun.star.document.LinkTarget",)

    # endregion Overrides
    # region Properties
    @property
    def component(self) -> LinkTarget:
        """LinkTarget Component"""
        return cast("LinkTarget", self._ComponentBase__get_component())  # type: ignore

    # endregion Properties

==> ooo_dev_tools-0.42.0-py3-none-any.whl: ooodev/adapter/document/link_target_comp.py <==
from __future__ import annotations
from typing import Any, cast, TYPE_CHECKING
from ooodev.adapter.beans.property_change_implement import PropertyChangeImplement
from ooodev.adapter.beans.vetoable_change_implement import VetoableChangeImplement
from ooodev.adapter.component_base import ComponentBase


if TYPE_CHECKING:
    from com.sun.star.document import LinkTarget  # service


class LinkTargetComp(ComponentBase, PropertyChangeImplement, VetoableChangeImplement):
    """
    Class for managing LinkTarget Component.
    """

    # pylint: disable=unused-argument

    def __init__(self, component: Any) -> None:
        """
        Constructor

        Args:
            component (Any): UNO component that supports ``com.sun.star.document.LinkTarget`` service.
        """
        ComponentBase.__init__(self, component)
        # pylint: disable=no-member
        generic_args = self._ComponentBase__get_generic_args()  # type: ignore
        PropertyChangeImplement.__init__(self, component=self.component, trigger_args=generic_args)
        VetoableChangeImplement.__init__(self, component=self.component, trigger_args=generic_args)

    # region Overrides
    def _ComponentBase__get_supported_service_names(self) -> tuple[str, ...]:
        """Returns a tuple of supported service names."""
        return ("com.sun.star.document.LinkTarget",)

    # endregion Overrides
    # region Properties
    @property
    def component(self) -> LinkTarget:
        """LinkTarget Component"""
        # pylint: disable=no-member
        return cast("LinkTarget", self._ComponentBase__get_component())  # type: ignore

    # endregion Properties
